import React from 'react';
import ReactDOM from 'react-dom';
import { interpolatePuBu, scaleSequential, max } from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { useData } from './useData';
import { useCodes } from './useCodes';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const selectedYear = "2017";

const App = () => {
  const worldAtlas = useWorldAtlas();
  const data = useData();
  const codes = useCodes();

  if (!worldAtlas || !data || !codes) {
    return <pre> Wait Loading...</pre>;
  }
  
  const numericCodeByAlphaCode = new Map();
  codes.forEach(code => {
    const alpha3Code = code["alpha-3"];
    const numericCode = code["country-code"];
    numericCodeByAlphaCode.set(alpha3Code, numericCode);
  });
  
  
  // Filter Data By Year 2017
  const filteredData = data.filter(d => d.Year === selectedYear);
  
  const rowByNumericCode = new Map();
  filteredData.forEach(d => {
    const alpha3Code = d.Code;
    const numericCode = numericCodeByAlphaCode.get(alpha3Code);
  	rowByNumericCode.set(numericCode, d);
  });
	
  // Country population that suffer a mental illness
  const colorValue = d => d.CountryPopulationWithMentalIllness;
	
  // Color scale 
  const colorScale = scaleSequential(interpolatePuBu)
    .domain([0, max(data, colorValue)]);
  
  return (
    <svg width={width} height={height}>
      <Marks
        worldAtlas={worldAtlas}
        rowByNumericCode={rowByNumericCode}
        colorScale={colorScale}
        colorValue={colorValue}
      />
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
